California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: PROPOSITION 012 - ESTABLISHES NEW STANDARDS FOR CONFINEMENT OF SPECIFIED FARM ANIMALS; BANS SALE OF NONCOMPLYING PRODUCTS. INITIATIVE STATUTE. View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1405877 | CALIFORNIANS AGAINST CRUELTY, CAGES AND FRAUD -- NO ON PROP 12 -- SPONSORED BY HUMANE FARMING ACTION FUND | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1404846 | OPEN PHILANTHROPY ACTION FUND YES PROP 12 (NONPROFIT 501(C)(4)) | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1399103 | YES ON PROP 12: PREVENT CRUELTY CALIFORNIA, A HUMANE SOCIETY COMMITTEE | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1412117 | ANIMAL EQUALITY NONPROFIT 501(C)(3), A COMMITTEE IN SUPPORT OF CALIFORNIA PROPOSITION 12 | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1412394 | HUMANE SOCIETY LEGISLATIVE FUND YES ON PROPOSITION 12 (NONPROFIT 501(C)(4)) | SUPPORT